from .track_id_enum import TrackIdEnum
from .mtrs_label_enum import MTRSLabelEnum
from .moderation_label_enum import ModerationLabelEnum

from .diagnostics_xml_tag_enum import DiagnosticsXMLTagEnum
from .mtrs_xml_tag_enum import MTRSXMLTagEnum
from .doctor_choice_xml_tag_enum import DoctorChoiceXMLTagEnum

StateEnum, ActionEnum = str, str



__version__ = "4.0.4"

from .logger import LogLevelEnum, logger_init
from .models import (
    TrackIdEnum,
    StateEnum,
    MTRSLabelEnum,
    ActionEnum,
    ModerationLabelEnum,
    ChatItem,
    InnerContextItem,
    OuterContextItem,
    ReplicaItem,
    ReplicaItemPair,
)
from .file_storage import FileStorage
from .models import DiagnosticsXMLTagEnum, MTRSXMLTagEnum, DoctorChoiceXMLTagEnum
from .utils import make_session_id, read_json
from .validators import is_file_exist, validate_prompt
from .xml_parser import XMLParser
from .parallel_map import parallel_map



import re
from enum import StrEnum


class XMLParser:
    @staticmethod
    def make_xml(body: str, tag: str | StrEnum) -> str:
        return f"<{tag}>{body}</{tag}>"

    @staticmethod
    def remove_xml(text: str) -> str:
        re_xml = re.compile(r"<(.*?)>")
        return re.sub(re_xml, "", text).replace("  ", " ").strip()

    @staticmethod
    def get_tag_list(response: str, tag: str | StrEnum) -> list[str]:
        tag_content = re.findall(f"<{tag}>(.*?)</{tag}>", response, re.DOTALL)
        return [content.lower().strip() for content in tag_content]



from enum import StrEnum, auto


class MTRSXMLTagEnum(StrEnum):
    @staticmethod
    def _generate_next_value_(name: str, start: int, count: int, last_values: list[str]) -> str:
        return f"mtrs_{name.lower()}"

    NAME = auto()
    LABEL = auto()
    DESC = auto()



from enum import StrEnum, auto


class MTRSLabelEnum(StrEnum):
    @staticmethod
    def _generate_next_value_(name: str, start: int, count: int, last_values: list[str]) -> str:
        return name.upper()

    LABORATORY = auto()
    INSTRUMENTAL = auto()



from enum import StrEnum, auto


class TrackIdEnum(StrEnum):
    @staticmethod
    def _generate_next_value_(name: str, start: int, count: int, last_values: list[str]) -> str:
        return "".join([word.title() for word in name.lower().split("_")])

    DIAGNOSTIC = auto()
    DIAGNOSTIC_SBERHEALTH = auto()
    SECOND_OPINION = auto()
    MEDICAL_TEST_DECRYPTION = auto()
    CONSULTATION = auto()
    DUMMY = auto()
    COMMON_CONSULTATION = auto()
    FINANCIER = auto()
    FINANCIER_GENERIC = auto()
    MULTIMODAL = auto()
